@@ -1,4 +1,4 @@
-/*	$Id: YSM.h,v 1.149 2006/02/12 19:51:22 rad2k Exp $	*/
+/*	$Id: YSM.h,v 1.151 2007/01/29 19:15:29 rad2k Exp $	*/
 /*
 -======================== ysmICQ client ============================-
 		Having fun with a boring Protocol
@@ -31,8 +31,8 @@ For Contact information read the AUTHORS file.
 #include "YSM_Config.h"
 #include "YSM_Compat.h"
 
-#define YSM_INFORMATION		"ysmICQ - Giving life to ICQ - "  
-#define YSM_INFORMATION2	"2.9.8"
+#define YSM_INFORMATION		"ysmICQ - Bringing ICQ back to life - "  
+#define YSM_INFORMATION2	"2.9.9.1"
 
 #ifdef WIN32
 #define YSM_CFGDIRECTORY	"ysm"
