@@ -1,4 +1,4 @@
-/*	$Id: YSM_Direct.c,v 1.74 2004/04/25 23:29:12 rad2k Exp $	*/
+/*	$Id: YSM_Direct.c,v 1.79 2005/09/04 01:36:48 rad2k Exp $	*/
 /*
 -======================== ysmICQ client ============================-
 		Having fun with a boring Protocol
@@ -26,7 +26,7 @@ For Contact information read the AUTHORS file.
 */
 
 #include "YSM.h"
-__RCSID("$Id: YSM_Direct.c,v 1.74 2004/04/25 23:29:12 rad2k Exp $");
+__RCSID("$Id: YSM_Direct.c,v 1.79 2005/09/04 01:36:48 rad2k Exp $");
 
 #include "YSM_ICQv7.h"
 #include "YSM_Direct.h"
@@ -112,7 +112,7 @@ int32_t	tmp;
 		return -1;
 	}
 
-	getsockname( sock, (struct sockaddr *)&addr, &tmp );
+	getsockname( sock, (struct sockaddr *)&addr, (int *)&tmp );
 	*port = addr.sin_port;
 	listen( sock, 3 );
 
@@ -145,7 +145,8 @@ YSM_SLAVE *
 YSM_DC_Wait4Client( void )
 {
 int32_t		cli_sock, addrlen, r_len;
-u_int32_t	r_ip1 = 0, r_ip2 = 0, r_uin = 0;
+u_int32_t	r_ip1 = 0, r_ip2 = 0;
+uin_t		r_uin = 0;
 struct		sockaddr_in addr;
 int8_t		buf[MAX_PEER_DATA_SIZE], pver = 0;
 struct		timeval tv;
@@ -156,7 +157,7 @@ YSM_SLAVE	*YSM_Query = NULL;
 	addrlen = sizeof(addr);
 	cli_sock = accept(YSM_USER.d_con.rSocket,
 				(struct sockaddr *)&addr,
-				&addrlen);
+				(int *)&addrlen);
 
 	if (cli_sock < 0) return NULL;
 
@@ -327,7 +328,7 @@ int r_len = 0, p_len = 0, x = 0;
 		return -1;
 
 	/* Read the command byte reply	*/
-	r_len = YSM_READ(cli_sock, buf, 2, 0, __FILE__, __LINE__);
+	r_len = YSM_READ(cli_sock, buf, 2, 0);
 	if (r_len <= 0) {
 		if (r_len < 0) {	
 			PRINTF( VERBOSE_DCON,
@@ -354,9 +355,7 @@ int r_len = 0, p_len = 0, x = 0;
 		x = YSM_READ( cli_sock,
 			&buf[0+r_len],
 			p_len,
-			0,
-			__FILE__,
-			__LINE__ );
+			0);
 
 		if (x < 0) {
 			PRINTF( VERBOSE_DCON,
@@ -648,6 +647,7 @@ YSM_CloseDC( YSM_SLAVE *victim )
 		"\nDC session to %s closed.\n", victim->info.NickName );
 #endif
 	g_promptstatus.flags |= FL_REDRAW;
+	g_promptstatus.flags |= FL_OVERWRITTEN;
 }
 
 void
@@ -856,8 +856,10 @@ int8_t		*pfname = NULL;
 			"Filename: '%s' [%d kb].\n",
 			pfname, fsize/1024 );
 
-		if (pfname != NULL)
+		if (pfname != NULL) {
 			YSM_Free(pfname, __FILE__, __LINE__);	
+			pfname = NULL;
+		}
 
 	} else ret = 0;
 
@@ -1455,6 +1457,7 @@ int32_t	ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.rSocket, buf, pos );
 	
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -1710,8 +1713,10 @@ int8_t		*pfname = NULL, *preason = NULL;
 	if (fnamelen) {		/* Filename buffer */
 		pfname = YSM_Calloc(1, fnamelen+1, __FILE__, __LINE__ );
 		if (!pfname) {
-			if (preason != NULL)
+			if (preason != NULL) {
 				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 			return -1;
 		}
 		memcpy( pfname, data+pos, fnamelen );
@@ -1733,26 +1738,30 @@ int8_t		*pfname = NULL, *preason = NULL;
 			"File transfer to %s aborted. (denied by the slave).\n",
 			victim->info.NickName);
 
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 			return 0;
 		case 0x04:
 			PRINTF( VERBOSE_BASE, "\n"
 			"File transfer to %s aborted. (the slave was away).\n",
 			victim->info.NickName);
 	
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 
 			return 0;
 		case 0x09:
@@ -1761,13 +1770,15 @@ int8_t		*pfname = NULL, *preason = NULL;
 			"(the slave was occupied).\n",
 			victim->info.NickName);
 
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 
 			return 0;
 		case 0x0a:
@@ -1776,13 +1787,15 @@ int8_t		*pfname = NULL, *preason = NULL;
 			"(the slave was in DND).\n",
 			victim->info.NickName);
 
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}	
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 
 			return 0;
 
@@ -1791,13 +1804,15 @@ int8_t		*pfname = NULL, *preason = NULL;
 			"File transfer to %s aborted. (the slave was in NA).\n",
 			victim->info.NickName);
 
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 
 			return 0;
 
@@ -1806,13 +1821,15 @@ int8_t		*pfname = NULL, *preason = NULL;
 			"File transfer to %s aborted. (m_status is unknown).\n",
 			victim->info.NickName);
 
-			if (pfname != NULL) YSM_Free( pfname,
-							__FILE__,
-							__LINE__ );
+			if (pfname != NULL) {
+				YSM_Free( pfname, __FILE__, __LINE__ );
+				pfname = NULL;
+			}
 
-			if (preason != NULL) YSM_Free( preason,
-							__FILE__,
-							__LINE__ );
+			if (preason != NULL) {
+				YSM_Free( preason, __FILE__, __LINE__ );
+				preason = NULL;
+			}
 
 			return 0;
 				
@@ -1871,8 +1888,15 @@ int8_t		*pfname = NULL, *preason = NULL;
 		
 	}
 
-	if (pfname != NULL) YSM_Free( pfname, __FILE__, __LINE__ );
-	if (preason != NULL) YSM_Free( preason, __FILE__, __LINE__ );
+	if (pfname != NULL) {
+		YSM_Free( pfname, __FILE__, __LINE__ );
+		pfname = NULL;
+	}
+
+	if (preason != NULL) {
+		YSM_Free( preason, __FILE__, __LINE__ );
+		preason = NULL;
+	}
 
 	return ret;
 }
@@ -1896,7 +1920,7 @@ fd_set	net_fd;
 	addrlen = sizeof(addr);
 	cli_sock = accept( victim->d_con.finfo.rSocket,
 			(struct sockaddr *)&addr,
-			&addrlen );
+			(int *)&addrlen );
 
 	if (cli_sock < 0) return -1;
 
@@ -2432,6 +2456,7 @@ int32_t	pos = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.finfo.rSocket, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2495,6 +2520,7 @@ int32_t	pos = 0, num_files = 0, num_bytes = 0, speed = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, sock, data, pos );
 
 	YSM_Free( data, __FILE__, __LINE__ );
+	data = NULL;
 	return ret;
 }
 
@@ -2552,6 +2578,7 @@ int32_t	pos = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.finfo.rSocket, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2627,6 +2654,7 @@ int32_t	pos = 0, num_bytes = 0, speed = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, sock, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2656,6 +2684,7 @@ int32_t	pos = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.finfo.rSocket, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2686,6 +2715,7 @@ int32_t	pos = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.finfo.rSocket, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2736,6 +2766,7 @@ int32_t	pos = 0, ret = TRUE;
 	ret = YSM_WRITE_DC( victim, victim->d_con.finfo.rSocket, buf, pos );
 
 	YSM_Free( buf, __FILE__, __LINE__ );
+	buf = NULL;
 	return ret;
 }
 
@@ -2762,6 +2793,7 @@ keyInstance	*crypt_key = NULL;
 	memcpy(&foffset, buf+1, 4);
 	if (fseek(victim->d_con.finfo.fd, foffset, SEEK_SET) != 0) {
 		YSM_Free( pread_buf, __FILE__, __LINE__ );
+		pread_buf = NULL;
 		return 0;
 	}
 
@@ -2805,10 +2837,15 @@ keyInstance	*crypt_key = NULL;
 					"transfer, aborting..\n" );
 
 				YSM_Free( pread_buf, __FILE__, __LINE__ );
-				if (crypt_key != NULL)
+				pread_buf = NULL;
+
+				if (crypt_key != NULL) {
 					YSM_Free( read_buf,
 						__FILE__,
 						__LINE__ );
+					read_buf = NULL;
+				}
+
 				return 0;
 			}
 		}
@@ -2848,8 +2885,12 @@ keyInstance	*crypt_key = NULL;
 	g_promptstatus.flags |= FL_REDRAW;
 
 	YSM_Free( pread_buf, __FILE__, __LINE__ );
-	if (crypt_key != NULL)
+	pread_buf = NULL;
+
+	if (crypt_key != NULL) {
 		YSM_Free( read_buf, __FILE__, __LINE__ );
+		read_buf = NULL;
+	}
 
 	return 0;
 }
@@ -2890,6 +2931,7 @@ struct stat	filestat;
 		if (mkdir(path, 0700)) {
 			PRINTF( VERBOSE_BASE, "Couldn't create directory.\n" );
 			YSM_Free( path, __FILE__, __LINE__ );
+			path = NULL;
 			return -1;
 		}
 	}
@@ -2917,10 +2959,12 @@ struct stat	filestat;
 	if (victim->d_con.finfo.fd == NULL) {
 		PRINTF( VERBOSE_BASE, "Unable to open %s for write.\n", path);
 		YSM_Free( path, __FILE__, __LINE__ );
+		path = NULL;
 		return -1;
 	}
 
 	YSM_Free( path, __FILE__, __LINE__ );
+	path = NULL;
 
 	return 0;
 }
