@@ -1,4 +1,4 @@
-/*	$Id: YSM_Win32.c,v 1.64 2004/07/04 19:41:57 rad2k Exp $	*/
+/*	$Id: YSM_Win32.c,v 1.66 2005/09/04 01:36:48 rad2k Exp $	*/
 /*
 -======================== ysmICQ client ============================-
 		Having fun with a boring Protocol
@@ -27,7 +27,7 @@ For Contact information read the AUTHORS file.
 */
 
 #include "YSM.h"
-__RCSID("$Id: YSM_Win32.c,v 1.64 2004/07/04 19:41:57 rad2k Exp $");
+__RCSID("$Id: YSM_Win32.c,v 1.66 2005/09/04 01:36:48 rad2k Exp $");
 
 #include "YSM_ToolBox.h"
 #include "YSM_Wrappers.h"
@@ -457,6 +457,29 @@ YSM_CreateHotKeyWindow(void)
 
 #else		/* UNIX */
 
+#ifndef OS2
+/* OS2 has its own WindowAlert rutine in YSM_os2.c */
+void
+YSM_WindowAlert(void)
+{
+	if (YSM_USER.fishgui.port && YSM_USER.fishgui.socket > 0
+		&& YSM_USER.fishgui.hide_console) return;
+
+	switch( YSM_SETTING_WINALERT )
+	{
+		case 0x1:
+		case 0x3:
+			PRINTF(VERBOSE_BASE, DECONIFY);
+			break;
+		case 0x2:
+		default:
+			break;
+	}
+
+	return;
+}
+#endif
+
 
 void
 CtrlHandler(int32_t sig)
@@ -528,7 +551,7 @@ gettxy(int *x, int *y)
 
 
 int
-getxy(int *x, int *y)
+getxy(int32_t *x, int32_t *y)
 {
 	char buf[20], *p, *q;
 	ssize_t r = 0, i = 0;
@@ -994,7 +1017,7 @@ char	pszNewWindowTitle[1024];
 	(void)snprintf( pszNewWindowTitle,
 			sizeof(pszNewWindowTitle),
 			"YSM ICQ [%d]",
-			YSM_USER.Uin );
+			(int)YSM_USER.Uin );
 
 #ifdef WIN32
 	/* Change current window title. */
